@@ -1,9 +1,6 @@
 package EWS::Client;
 BEGIN {
-  $EWS::Client::VERSION = '1.141040';
-}
-BEGIN {
-  $EWS::Client::VERSION = '1.130570';
+  $EWS::Client::VERSION = '1.143070';
 }
 use Moose;
 
@@ -13,10 +10,12 @@ with qw/
     EWS::Client::Role::FindItem
     EWS::Client::Role::FindFolder
     EWS::Client::Role::GetFolder
+    EWS::Client::Role::ExpandDL
 /;
 use EWS::Client::Contacts;
 use EWS::Client::Calendar;
 use EWS::Client::Folder;
+use EWS::Client::DistributionList;
 use URI::Escape ();
 use Log::Report;
 
@@ -71,6 +70,16 @@ sub _build_folders {
     return EWS::Client::Folder->new({ client => $self });
 }
 
+has distribution_list => (
+    is => 'ro',
+    isa => 'EWS::Client::DistributionList',
+    lazy_build => 1,
+);
+
+sub _build_distribution_list {
+    my $self = shift;
+    return EWS::Client::DistributionList->new({ client => $self });
+}
 
 sub BUILDARGS {
     my ($class, @rest) = @_;
@@ -119,7 +128,7 @@ EWS::Client - Microsoft Exchange Web Services Client
 
 =head1 VERSION
 
-version 1.141040
+version 1.143070
 
 =head1 SYNOPSIS
 
@@ -232,6 +241,12 @@ Retrieves the L<EWS::Client::Folder> object which allows retrieval of
 mailbox folder entries and their sizes. See that linked manual page for
 more details.
 
+=head2 $ews->dls()
+
+Retrieves the L<EWS::Client::DistributionList> object which allows retrieval of
+distribution list entries and their email addresses and names. See that linked
+manual page for more details.
+
 =head1 KNOWN ISSUES
 
 =over 4
